@@ -28,6 +28,7 @@ from contextlib import contextmanager
 import io
 import math
 from string import Formatter
+from warnings import warn
 import zipfile
 
 import numpy as np
@@ -37,10 +38,10 @@ from obspy.core.event import (
     ResourceIdentifier)
 
 
-__version__ = '0.6.0'
+__version__ = '0.8.0'
 
 # for reading
-DEFAULT = {'magtype': None}
+DEFAULT = {'magtype': ''}
 # for writing
 FIELDS = {
     'basic': '{time!s:.25} {lat:.6f} {lon:.6f} {dep:.3f} {mag:.2f} {magtype} {id}'
@@ -60,6 +61,9 @@ DTYPE = {
     'id': 'U50'
     }
 
+#EventID | Time | Latitude | Longitude | Depth/km | Author | Catalog | Contributor | ContributorID | MagType | Magnitude | MagAuthor | EventLocationName
+NAMES_EVENTTXT = 'id time lat lon dep _ _ _ _ magtype mag _ _'
+
 
 def _is_csv(fname, **kwargs):
     try:
@@ -68,6 +72,13 @@ def _is_csv(fname, **kwargs):
         return False
 
 
+def _is_eventtxt(fname, **kwargs):
+    try:
+        return read_eventtxt(fname, format_check=True)
+    except:
+        return False
+
+
 def _is_csz(fname, **kwargs):
     try:
         assert zipfile.is_zipfile(fname)
@@ -162,7 +173,8 @@ def _read_picks(event, fname):
         reader = csv.DictReader(f)
         for row in reader:
             phase = row['phase']
-            wid = WaveformStreamID(seed_string=row['seedid'])
+            seedid = row['seedid']
+            wid = WaveformStreamID(seed_string=seedid) if seedid else None
             pick = Pick(waveform_id=wid, phase_hint=phase,
                         time=otime + float(row['time']))
             arrival = Arrival(phase=phase, pick_id=pick.resource_id,
@@ -189,8 +201,13 @@ def _write_picks(event, fname, fields_picks='basic', delimiter=','):
         f.write(delimiter.join(fieldnames) + '\n')
         for pick in event.picks:
             pick_id = str(pick.resource_id)
+            try:
+                seedid = pick.waveform_id.id
+            except:
+                warn(f'No waveform id found for pick {pick_id}')
+                seedid = ''
             d = {'time': pick.time - origin.time,
-                 'seedid': pick.waveform_id.id,
+                 'seedid': seedid,
                  'phase': phases.get(pick_id, pick.phase_hint),
                  'weight': weights.get(pick_id, 1.)}
             f.write(fmtstr.format(**d) + '\n')
@@ -204,6 +221,12 @@ def _names_sequence(names):
     return names
 
 
+def read_eventtxt(fname, default=None, format_check=False):
+    return read_csv(fname,
+                    skipheader=1, names=NAMES_EVENTTXT, delimiter='|',
+                    default=default, format_check=format_check)
+
+
 def read_csv(fname, skipheader=0, depth_in_km=True, default=None, names=None,
              check_compression=None, format_check=False,
              **kwargs):
@@ -244,11 +267,16 @@ def read_csv(fname, skipheader=0, depth_in_km=True, default=None, names=None,
                 time = UTC(row['time'])
             else:
                 time = UTC('{year}-{mon}-{day} {hour}:{minu}:{sec}'.format(**row))
-            dep = float(row['dep']) * (1000 if depth_in_km else 1)
+            try:
+                dep = float(row['dep']) * (1000 if depth_in_km else 1)
+                if math.isnan(dep):
+                    raise
+            except:
+                dep = None
             origin = Origin(time=time, latitude=row['lat'], longitude=row['lon'], depth=dep)
             try:
                 # add zero to eliminate negative zeros in magnitudes
-                mag = float(row['mag'])+0
+                mag = float(row['mag']) + 0
                 if math.isnan(mag):
                     raise
             except:
@@ -256,11 +284,10 @@ def read_csv(fname, skipheader=0, depth_in_km=True, default=None, names=None,
             else:
                 try:
                     magtype = row['magtype']
+                    if magtype.lower() in ('', 'none', 'null', 'nan'):
+                        raise
                 except:
-                    magtype = DEFAULT.get('magtype')
-                else:
-                    if magtype.lower() in ('none', 'null', 'nan'):
-                        magtype = None
+                    magtype = default.get('magtype')
                 magnitudes = [Magnitude(mag=mag, magnitude_type=magtype)]
             id_ = ResourceIdentifier(row['id'].strip()) if 'id' in row else None
             event = Event(magnitudes=magnitudes, origins=[origin], resource_id=id_)
@@ -305,27 +332,30 @@ def write_csv(events, fname, fields='basic', depth_in_km=True, delimiter=','):
             try:
                 origin = _origin(event)
             except:
-                from warnings import warn
                 warn(f'No origin found -> do not write event {evid}')
                 continue
             try:
                 magnitude = event.preferred_magnitude() or event.magnitudes[0]
             except:
-                from warnings import warn
                 warn(f'No magnitude found for event {evid}')
                 mag = float('nan')
-                magtype = None
+                magtype = ''
             else:
                 mag = magnitude.mag
-                magtype = magnitude.magnitude_type
+                magtype = magnitude.magnitude_type or ''
+            try:
+                dep = origin.depth / (1000 if depth_in_km else 1)
+            except:
+                warn(f'No depth set for event {evid}')
+                dep = float('nan')
             d = {'time': origin.time,
                  'lat': origin.latitude,
                  'lon': origin.longitude,
-                 'dep': origin.depth / (1000 if depth_in_km else 1),
+                 'dep': dep,
                  'mag': mag,
                  'magtype': magtype,
                  'id': evid}
-            f.write(fmtstr.format(**d) + '\n')
+            f.write(fmtstr.format(**d).replace('nan', '') + '\n')
 
 
 def load_csv(fname, skipheader=0, only=None, names=None, **kw):
@@ -355,7 +385,7 @@ def load_csv(fname, skipheader=0, only=None, names=None, **kw):
         kw.setdefault('usecols', usecols)
         kw.setdefault('dtype', dtype)
         kw.setdefault('delimiter', ',')
-        return np.loadtxt(f, **kw)
+        return np.genfromtxt(f, **kw)
 
 
 def events2array(events, **kw):
