@@ -47,6 +47,7 @@ class CSVCSZTestCase(unittest.TestCase):
         del events[0].magnitudes[0].magnitude_type
         events[1].magnitudes = []
         events[1].preferred_magnitude_id = None
+        events[1].origins[0].depth = None
         events[2].origins = []
         events[2].preferred_origin_id = None
         with NamedTemporaryFile(suffix='.csv') as ft:
@@ -56,8 +57,23 @@ class CSVCSZTestCase(unittest.TestCase):
         self.assertEqual(len(events2), 2)
         self.assertEqual(events2[0].origins[0].time,
                           events[0].origins[0].time)
+        self.assertIs(events2[1].origins[0].depth, None)
         self.assertEqual(events2[1].origins[0].time,
                           events[1].origins[0].time)
+        csv = """time,lat,lon,dep,mag,magtype,id
+2012-04-04,42,42,nan,null,,id1
+2012-04-04,42,42,,10,Munreal,id1"""
+        with NamedTemporaryFile(suffix='.txt') as ft:
+            with open(ft.name, 'w') as f:
+                f.write(csv)
+            self.assertTrue(obspycsv._is_csv(ft.name))
+            events = read_events(ft.name)
+        self.assertEqual(len(events), 2)
+        self.assertIs(events[0].origins[0].depth, None)
+        self.assertEqual(len(events[0].magnitudes), 0)
+        self.assertIs(events[1].origins[0].depth, None)
+        self.assertEqual(len(events[1].magnitudes), 1)
+        self.assertEqual(events[1].magnitudes[0].mag, 10.0)
 
     def test_csv_custom_fmt(self):
         events = read_events()
@@ -98,8 +114,9 @@ class CSVCSZTestCase(unittest.TestCase):
                 pass
             else:
                 _test_write_read(events, compression=True, compresslevel=6)
-            # test with missing origin
+            # test with missing origin and waveformid
             events[1].origins = []
+            events[0].picks[0].waveform_id = None
             with self.assertWarns(Warning):
                 events.write(fname, 'CSZ')
             self.assertTrue(obspycsv._is_csz(fname))
@@ -174,6 +191,24 @@ class CSVCSZTestCase(unittest.TestCase):
         t = obspycsv.events2array(events)
         self.assertEqual(t['mag'][0], 4.4)
 
+    def test_eventtxt(self):
+        eventtxt = """#EventID | Time | Latitude | Longitude | Depth/km | Author | Catalog | Contributor | ContributorID | MagType | Magnitude | MagAuthor | EventLocationName
+3337497|2012-04-11T08:38:37|2.2376|93.0144|26.3|ISC|ISC|ISC|600860404|MW|8.6|GCMT|OFF W COAST OF NORTHERN SUMATRA
+3279407|2011-03-11T05:46:23|38.2963|142.498|19.7|ISC|ISC|ISC|16461282|MW|9.1|GCMT|NEAR EAST COAST OF HONSHU, JAPAN
+2844986|2010-02-27T06:34:13|-36.1485|-72.9327|28.1|ISC|ISC|ISC|14340585|MW|8.8|GCMT|NEAR COAST OF CENTRAL CHILE
+2559759|2007-09-12T11:10:26|-4.4637|101.3959|35.5|ISC|ISC|ISC|13203322|MW|8.5|GCMT|SOUTHERN SUMATRA, INDONESIA
+2092067|2005-03-28T16:09:35|2.0964|97.1131|30.0|ISC|ISC|ISC|7486110|MW|8.6|HRVD|NORTHERN SUMATRA, INDONESIA
+1916079|2004-12-26T00:58:52|3.4125|95.9012|26.1|ISC|ISC|ISC|7453151|MW|9.0|HRVD|OFF W COAST OF NORTHERN SUMATRA
+2413|1960-05-22T19:11:14|-38.17|-72.57|0.0|ISS|ISC|ISC|879136||8.5|PAS|CENTRAL CHILE"""
+        with NamedTemporaryFile(suffix='.txt') as ft:
+            with open(ft.name, 'w') as f:
+                f.write(eventtxt)
+            self.assertTrue(obspycsv._is_eventtxt(ft.name))
+            events = read_events(ft.name)
+        self.assertEqual(len(events), 7)
+        self.assertEqual(str(events[0].origins[0].time), '2012-04-11T08:38:37.000000Z')
+        self.assertEqual(len(events[0].magnitudes), 1)
+
 
 def suite():
     return unittest.makeSuite(CSVCSZTestCase, 'test')
